pub struct CompletionAcceptance {
pub replacement: String,
pub cursor: usize,
}Expand description
A candidate’s whole-buffer replacement and cursor position at acceptance.
Fields
replacement: StringBuffer contents to install when the user accepts the candidate.
cursor: usizeUTF-8 byte offset at which to place the prompt cursor in replacement.